aboutsummaryrefslogtreecommitdiffstats
path: root/ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt
diff options
context:
space:
mode:
Diffstat (limited to 'ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt')
-rw-r--r--ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt4
1 files changed, 2 insertions, 2 deletions
diff --git a/ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt b/ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt
index d2206df51..d2f02028c 100644
--- a/ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt
+++ b/ms/blueprintsprocessor/modules/inbounds/health-api/src/main/kotlin/org/onap/ccsdk/cds/blueprintsprocessor/healthapi/controller/CombinedMetrics.kt
@@ -28,7 +28,7 @@ import org.springframework.web.bind.annotation.ResponseBody
import org.springframework.web.bind.annotation.RestController
/**
* Exposes API for checking Metrics of Blueprint processor and CDSListener.
*
* @author Shaaban Ebrahim
* @version 1.0
@@ -37,7 +37,7 @@ import org.springframework.web.bind.annotation.RestController
@RequestMapping("/api/v1/combinedMetrics")
@Api(
value = "/api/v1/combinedMetrics",
- description = "gather all Metrics info from Blueprint and CDSListener"
+ description = "gather all Metrics info from BluePrint and CDSListener"
)
open class CombinedMetrics(private val combinedMetricsService: CombinedMetricsService) {
@@ -28,7 +28,7 @@ import org.springframework.web.bind.annotation.ResponseBody
import org.springframework.web.bind.annotation.RestController
/**
- * Exposes API for checking Metrics of Blueprint processor and CDSListener.
+ * Exposes API for checking Metrics of BluePrint processor and CDSListener.
*
* @author Shaaban Ebrahim